==> haskell-lua-arbitrary-1.0.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-6zdD2UWXNtsFE3AnRHrloN
key:                  lua-arbitrary-1.0.1.1-6zdD2UWXNtsFE3AnRHrloN
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  40d4d2a3fbae45d38467818ed7774ece
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-6zdD2UWXNtsFE3AnRHrloN
depends:
    QuickCheck-2.14.3-1OE8Tk6Cvw85tkUdApuCR4 base-4.15.1.0
    lua-2.3.1-KmEkn03mfrB6wt95na6o7l

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-9gjmfPezedw963kpV2Yb7d
key:                  lua-arbitrary-1.0.1.1-9gjmfPezedw963kpV2Yb7d
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  68ae264acd85720fa189c7d250c0d33f
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-9gjmfPezedw963kpV2Yb7d
depends:
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc base-4.16.4.0
    lua-2.3.2-CW5U8pmQtcGIvTgmqAkLf9

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
